pub fn commit(
ccm: &ConventionalCommitMessage,
cwd: Option<&str>,
) -> Result<CommitInfo>Expand description
Commit the changes to the repository with the given commit message in the directory specified by
cwd. If cwd is not provided, the current working directory is used.
Returns a CommitResult which is either a Commit or the error returned by the git command.